@@ -60,12 +60,6 @@ void Fl_Wayland_Window_Driver::destroy_double_buffer() {
 }
 
 
-Fl_Window_Driver *Fl_Window_Driver::newWindowDriver(Fl_Window *w)
-{
-  return new Fl_Wayland_Window_Driver(w);
-}
-
-
 Fl_Wayland_Window_Driver::Fl_Wayland_Window_Driver(Fl_Window *win) : Fl_Window_Driver(win)
 {
   icon_ = new icon_data;
@@ -396,6 +390,10 @@ void Fl_Wayland_Window_Driver::make_current() {
   
   struct wld_window *window = fl_xid(pWindow);
   float scale = Fl::screen_scale(pWindow->screen_num()) * window->scale;
+  if (window && window->buffer) {
+    ((Fl_Cairo_Graphics_Driver*)fl_graphics_driver)->needs_commit_tag(
+                                            &window->buffer->draw_buffer_needs_commit);
+  }
 
   // to support progressive drawing
   if ( (!Fl_Wayland_Window_Driver::in_flush) && window && window->buffer && (!window->buffer->cb)) {
@@ -408,8 +406,12 @@ void Fl_Wayland_Window_Driver::make_current() {
 
   fl_graphics_driver->clip_region(0);
   fl_window = window;
-  if (!window->buffer) window->buffer = Fl_Wayland_Graphics_Driver::create_shm_buffer(
+  if (!window->buffer) {
+    window->buffer = Fl_Wayland_Graphics_Driver::create_shm_buffer(
            pWindow->w() * scale, pWindow->h() * scale);
+    ((Fl_Cairo_Graphics_Driver*)fl_graphics_driver)->needs_commit_tag(
+                                            &window->buffer->draw_buffer_needs_commit);
+  }
   ((Fl_Wayland_Graphics_Driver*)fl_graphics_driver)->activate(window->buffer, scale);
 
 #ifdef FLTK_USE_CAIRO
@@ -1392,7 +1394,7 @@ void Fl_Wayland_Window_Driver::fullscreen_off(int X, int Y, int W, int H) {
 
 
 void Fl_Wayland_Window_Driver::label(const char *name, const char *iname) {
-  if (shown() && !parent()) {
+  if (shown() && !parent() && fl_xid(pWindow)->kind == DECORATED) {
     if (!name) name = "";
     if (!iname) iname = fl_filename_name(name);
     libdecor_frame_set_title(fl_xid(pWindow)->frame, name);
@@ -1580,3 +1582,12 @@ void Fl_Wayland_Window_Driver::menu_window_area(int &X, int &Y, int &W, int &H,
     //printf("menu_window_area: %dx%d - %dx%d\n",X,Y,W,H);
   } else Fl_Window_Driver::menu_window_area(X, Y, W, H, nscreen);
 }
+
+
+FL_EXPORT struct wl_surface *fl_wl_surface(Window xid) {
+  return xid->wl_surface;
+}
+
+FL_EXPORT struct _cairo *fl_wl_cairo() {
+  return ((Fl_Cairo_Graphics_Driver*)fl_graphics_driver)->cr();
+}
