@@ -30,6 +30,10 @@ extern "C" void cfltk_setWindowTransparency(void *, unsigned char);
 #include <FL/fl_draw.H>
 #include <FL/platform.H>
 
+#if defined (FLTK_USE_WAYLAND)
+#include <cairo/cairo.h>
+#endif
+
 #include <stdint.h>
 #include <stdlib.h>
 
@@ -66,7 +70,11 @@ struct Window_Derived : public Widget_Derived<Win> {
         Atom atom = XInternAtom(fl_display, "_NET_WM_WINDOW_OPACITY", False);
         XChangeProperty(fl_display, fl_xid(this), atom, XA_CARDINAL, 32, PropModeReplace,
                         (unsigned char *)&cardinal_alpha, 1);
-#else                        
+#elif defined(FLTK_USE_WAYLAND)
+    auto cr = fl_wl_cairo();
+    cairo_set_source_rgba(cr, 0, 0, 0, (float)alpha/255.0);
+    cairo_save(cr);
+#else                       
 #endif
         alpha_ = alpha;
     }
@@ -234,8 +242,11 @@ Fl_Window *Fl_Window_find_by_handle(void *handle) {
 
 winid resolve_raw_handle(void *handle) {
     winid w;
-#if defined(_WIN32) || defined(__APPLE__) || defined(__ANDROID__) || defined(FLTK_USE_WAYLAND)
+#if defined(_WIN32) || defined(__APPLE__) || defined(__ANDROID__)
     w.opaque = *(Window *)handle;
+#elif defined (FLTK_USE_WAYLAND)
+    auto h = fl_wl_surface(*(Window *)handle);
+    w.opaque = h;
 #else
     w.x_id = *(Window *)handle;
 #endif
